Stop using SiRF state info.
[fw/altos] / src / ao.h
index 84e92f35e77ced7eb5c581c6c43230f9eabc110f..b72cac5c4aac6ddbe524cff75d41b7d2f8344a2a 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -40,6 +40,7 @@
 /* An AltOS task */
 struct ao_task {
        __xdata void *wchan;            /* current wait channel (NULL if running) */
+       uint16_t alarm;                 /* abort ao_sleep time */
        uint8_t stack_count;            /* amount of saved stack */
        uint8_t task_id;                /* index in the task array */
        __code char *name;              /* task name */
@@ -55,8 +56,12 @@ extern __xdata struct ao_task *__data ao_cur_task;
  ao_task.c
  */
 
-/* Suspend the current task until wchan is awoken */
-void
+/* Suspend the current task until wchan is awoken.
+ * returns:
+ *  0 on normal wake
+ *  1 on alarm
+ */
+uint8_t
 ao_sleep(__xdata void *wchan);
 
 /* Wake all tasks sleeping on wchan */
@@ -67,6 +72,10 @@ ao_wakeup(__xdata void *wchan);
 void
 ao_wake_task(__xdata struct ao_task *task);
 
+/* set an alarm to go off in 'delay' ticks */
+void
+ao_alarm(uint16_t delay);
+
 /* Yield the processor to another task */
 void
 ao_yield(void) _naked;
@@ -97,6 +106,8 @@ ao_start_scheduler(void);
 #define AO_PANIC_EE            4       /* Mis-using eeprom API */
 #define AO_PANIC_LOG           5       /* Failing to read/write log data */
 #define AO_PANIC_CMD           6       /* Too many command sets registered */
+#define AO_PANIC_STDIO         7       /* Too many stdio handlers registered */
+#define AO_PANIC_REBOOT                8       /* Reboot failed */
 
 /* Stop the operating system, beeping and blinking the reason */
 void
@@ -107,8 +118,9 @@ ao_panic(uint8_t reason);
  */
 
 /* Our timer runs at 100Hz */
-#define AO_MS_TO_TICKS(ms)     ((ms) / 10)
-#define AO_SEC_TO_TICKS(s)     ((s) * 100)
+#define AO_HERTZ               100
+#define AO_MS_TO_TICKS(ms)     ((ms) / (1000 / AO_HERTZ))
+#define AO_SEC_TO_TICKS(s)     ((s) * AO_HERTZ)
 
 /* Returns the current time in ticks */
 uint16_t
@@ -281,6 +293,12 @@ ao_usb_putchar(char c);
 char
 ao_usb_getchar(void);
 
+/* Poll for a charcter on the USB input queue.
+ * returns AO_READ_AGAIN if none are available
+ */
+char
+ao_usb_pollchar(void);
+
 /* Flush the USB output queue */
 void
 ao_usb_flush(void);
@@ -333,6 +351,9 @@ ao_cmd_hex(void);
 void
 ao_cmd_decimal(void);
 
+uint8_t
+ao_match_word(__code char *word);
+
 struct ao_cmds {
        char            cmd;
        void            (*func)(void);
@@ -356,7 +377,6 @@ ao_cmd_init(void);
 
 #define AO_DMA_DONE    1
 #define AO_DMA_ABORTED 2
-#define AO_DMA_TIMEOUT 4
 
 uint8_t
 ao_dma_alloc(__xdata uint8_t * done);
@@ -380,7 +400,7 @@ ao_dma_trigger(uint8_t id);
 
 /* Abort a running DMA transfer */
 void
-ao_dma_abort(uint8_t id, uint8_t reason);
+ao_dma_abort(uint8_t id);
 
 /* DMA interrupt routine */
 void
@@ -473,6 +493,7 @@ ao_ee_init(void);
 #define AO_LOG_GPS_LON         'W'
 #define AO_LOG_GPS_ALT         'H'
 #define AO_LOG_GPS_SAT         'V'
+#define AO_LOG_GPS_DATE                'Y'
 
 #define AO_LOG_POS_NONE                (~0UL)
 
@@ -515,9 +536,14 @@ struct ao_log_record {
                } gps_altitude;
                struct {
                        uint16_t        svid;
-                       uint8_t         state;
+                       uint8_t         unused;
                        uint8_t         c_n;
                } gps_sat;
+               struct {
+                       uint8_t         year;
+                       uint8_t         month;
+                       uint8_t         day;
+               } gps_date;
                struct {
                        uint16_t        d0;
                        uint16_t        d1;
@@ -533,11 +559,11 @@ ao_log_data(struct ao_log_record *log);
 void
 ao_log_flush(void);
 
-/* Log dumping API:
- * ao_log_dump_first() - get first log record
- * ao_log_dump_next()  - get next log record
+/* We record flight numbers in the first record of
+ * the log. Tasks may wait for this to be initialized
+ * by sleeping on this variable.
  */
-extern __xdata struct ao_log_record ao_log_dump;
+extern __xdata uint16_t ao_flight_number;
 
 /* Retrieve first log record for the current flight */
 uint8_t
@@ -700,8 +726,12 @@ ao_serial_init(void);
 
 #define AO_GPS_VALID           (1 << 4)
 #define AO_GPS_RUNNING         (1 << 5)
+#define AO_GPS_DATE_VALID      (1 << 6)
 
 struct ao_gps_data {
+       uint8_t                 year;
+       uint8_t                 month;
+       uint8_t                 day;
        uint8_t                 hour;
        uint8_t                 minute;
        uint8_t                 second;
@@ -717,18 +747,8 @@ struct ao_gps_data {
        uint16_t                v_error;        /* m */
 };
 
-#define SIRF_SAT_STATE_ACQUIRED                        (1 << 0)
-#define SIRF_SAT_STATE_CARRIER_PHASE_VALID     (1 << 1)
-#define SIRF_SAT_BIT_SYNC_COMPLETE             (1 << 2)
-#define SIRF_SAT_SUBFRAME_SYNC_COMPLETE                (1 << 3)
-#define SIRF_SAT_CARRIER_PULLIN_COMPLETE       (1 << 4)
-#define SIRF_SAT_CODE_LOCKED                   (1 << 5)
-#define SIRF_SAT_ACQUISITION_FAILED            (1 << 6)
-#define SIRF_SAT_EPHEMERIS_AVAILABLE           (1 << 7)
-
 struct ao_gps_sat_data {
        uint8_t         svid;
-       uint8_t         state;
        uint8_t         c_n_1;
 };
 
@@ -768,15 +788,19 @@ ao_gps_report_init(void);
  */
 
 #define AO_MAX_CALLSIGN                8
+#define AO_TELEMETRY_VERSION   2
 
 struct ao_telemetry {
        uint8_t                 addr;
+       uint16_t                flight;
        uint8_t                 flight_state;
        int16_t                 flight_accel;
        int16_t                 ground_accel;
        int32_t                 flight_vel;
        int16_t                 flight_pres;
        int16_t                 ground_pres;
+       int16_t                 accel_plus_g;
+       int16_t                 accel_minus_g;
        struct ao_adc           adc;
        struct ao_gps_data      gps;
        char                    callsign[AO_MAX_CALLSIGN];
@@ -835,7 +859,7 @@ void
 ao_radio_rdf(int ms);
 
 void
-ao_radio_abort(uint8_t reason);
+ao_radio_abort(void);
 
 void
 ao_radio_rdf_abort(void);
@@ -865,9 +889,24 @@ ao_monitor_init(uint8_t led, uint8_t monitoring) __reentrant;
  * ao_stdio.c
  */
 
+#define AO_READ_AGAIN  ((char) -1)
+
+struct ao_stdio {
+       char    (*pollchar)(void);
+       void    (*putchar)(char c) __reentrant;
+       void    (*flush)(void);
+};
+
 void
 flush(void);
 
+extern __xdata uint8_t ao_stdin_ready;
+
+void
+ao_add_stdio(char (*pollchar)(void),
+            void (*putchar)(char) __reentrant,
+            void (*flush)(void));
+
 /*
  * ao_ignite.c
  */
@@ -898,16 +937,17 @@ ao_igniter_init(void);
  */
 
 #define AO_CONFIG_MAJOR        1
-#define AO_CONFIG_MINOR        1
+#define AO_CONFIG_MINOR        2
 
 struct ao_config {
        uint8_t         major;
        uint8_t         minor;
        uint16_t        main_deploy;
-       int16_t         accel_zero_g;
+       int16_t         accel_plus_g;
        uint8_t         radio_channel;
        char            callsign[AO_MAX_CALLSIGN + 1];
        uint8_t         apogee_delay;
+       int16_t         accel_minus_g;
 };
 
 extern __xdata struct ao_config ao_config;
@@ -973,6 +1013,7 @@ struct ao_fifo {
  */
 
 #define AO_PACKET_MAX  8
+#define AO_PACKET_SYN          (uint8_t) 0xff
 
 struct ao_packet {
        uint8_t         addr;
@@ -988,7 +1029,42 @@ struct ao_packet_recv {
        uint8_t                 status;
 };
 
+extern __xdata struct ao_packet_recv ao_rx_packet;
+extern __xdata struct ao_packet ao_tx_packet;
+extern __xdata struct ao_task  ao_packet_task;
+extern __xdata uint8_t ao_packet_enable;
+extern __xdata uint8_t ao_packet_master_sleeping;
+extern __pdata uint8_t ao_packet_rx_len, ao_packet_rx_used, ao_packet_tx_used;
+
+void
+ao_packet_send(void);
+
+uint8_t
+ao_packet_recv(void);
+
+void
+ao_packet_flush(void);
+
+void
+ao_packet_putchar(char c) __reentrant;
+
+char
+ao_packet_pollchar(void) __critical;
+
+/* ao_packet_master.c */
+
+void
+ao_packet_master_init(void);
+
+/* ao_packet_slave.c */
+
+void
+ao_packet_slave_start(void);
+
+void
+ao_packet_slave_stop(void);
+
 void
-ao_packet_init(void);
+ao_packet_slave_init(void);
 
 #endif /* _AO_H_ */